##  Completing To-Do Tasks
By default, any user can complete a to-do item unless the administrator has restricted it to the assignee. To learn more, see [Restricting To-Do Completion to Assignees](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ad8677a441014bd85fc1784a4ff30__restricting_to-do_completion_to_assignees)
Depending on the type of to-do, you complete the to-do in the following ways:
  * For an action item to-do, choose Mark as Complete after the task is completed.
![Marking an Action Item To-Do as Complete](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27511d2f7a4410149cb8ec37ac1ef8fc_LowRes.png)
Marking an Action Item To-Do as Complete
  * For an ask question to-do, provide the needed answer and chooseReply and Close.
  * For an approval to-do, you can Approve or Reject the item. When you reject the request, you are prompted to provide a reason.


**Tip**
If you need clarification before approving or rejecting, use an ask question to-do, or the comments feature to collaborate.
When to-dos are completed, their status changes to Closed. The Resolution column indicates whether they were accepted or rejected by the creator of the task.
To remove unfinished tasks after the due date has passed, you can select Close unresolved.
![Close Unresolved Tasks](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752f3b77a4410148026a89865506668_LowRes.png)
Close Unresolved Tasks
**Note**
Completed to-dos disappear once the page is refreshed.
